==> aucmedi-0.3.0.tar.gz: aucmedi-0.3.0/aucmedi/data_processing/subfunctions/__init__.py <==
#==============================================================================#
#  Author:       Dominik Müller                                                #
#  Copyright:    2021 IT-Infrastructure for Translational Medical Research,    #
#                University of Augsburg                                        #
#                                                                              #
#  This program is free software: you can redistribute it and/or modify        #
#  it under the terms of the GNU General Public License as published by        #
#  the Free Software Foundation, either version 3 of the License, or           #
#  (at your option) any later version.                                         #
#                                                                              #
#  This program is distributed in the hope that it will be useful,             #
#  but WITHOUT ANY WARRANTY; without even the implied warranty of              #
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
#  GNU General Public License for more details.                                #
#                                                                              #
#  You should have received a copy of the GNU General Public License           #
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#==============================================================================#
from aucmedi.data_processing.subfunctions.standardize import Standardize
from aucmedi.data_processing.subfunctions.resize import Resize
from aucmedi.data_processing.subfunctions.padding import Padding
from aucmedi.data_processing.subfunctions.crop import Crop

==> aucmedi-0.4.0.tar.gz: aucmedi-0.4.0/aucmedi/data_processing/subfunctions/__init__.py <==
#==============================================================================#
#  Author:       Dominik Müller                                                #
#  Copyright:    2022 IT-Infrastructure for Translational Medical Research,    #
#                University of Augsburg                                        #
#                                                                              #
#  This program is free software: you can redistribute it and/or modify        #
#  it under the terms of the GNU General Public License as published by        #
#  the Free Software Foundation, either version 3 of the License, or           #
#  (at your option) any later version.                                         #
#                                                                              #
#  This program is distributed in the hope that it will be useful,             #
#  but WITHOUT ANY WARRANTY; without even the implied warranty of              #
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
#  GNU General Public License for more details.                                #
#                                                                              #
#  You should have received a copy of the GNU General Public License           #
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#==============================================================================#
from aucmedi.data_processing.subfunctions.standardize import Standardize
from aucmedi.data_processing.subfunctions.resize import Resize
from aucmedi.data_processing.subfunctions.padding import Padding
from aucmedi.data_processing.subfunctions.crop import Crop
from aucmedi.data_processing.subfunctions.color_constancy import ColorConstancy
from aucmedi.data_processing.subfunctions.clip import Clip
from aucmedi.data_processing.subfunctions.chromer import Chromer
